@@ -26,11 +26,12 @@
 #               0.2.7 | dantezhu | 2013-07-16 01:28:20 | 增加js直接渲染
 #               0.2.8 | dantezhu | 2013-07-16 12:04:23 | 使用encodeURIComponent，否则中文有问题
 #               0.2.9 | dantezhu | 2013-07-16 12:04:23 | 用tojson，支持直接放到html中
+#               0.2.10 | dantezhu | 2013-07-19 11:10:41 | 必要的时候抛出异常
 #
 #=============================================================================
 '''
 
-__version__ = (0, 2, 9)
+__version__ = (0, 2, 10)
 
 from flask import Response, Markup
 from flask import current_app
@@ -48,9 +49,11 @@ var flask_util = function() {
         if (!params) {
             params = {};
         }
+
         if (!url_map[endpoint]) {
-            return '';
+            throw('endpoint is not exist: ' + endpoint);
         }
+
         var rule = url_map[endpoint]['rule'];
 
         var used_params = {};
